PNetworkOptionsOther class

Inheritance

Constructors

PNetworkOptionsOther({String baseUrl = '', String baseUrlAsset = ''})

Properties

baseUrl → String
finalinherited
baseUrlAsset → String
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
mqttPort → int?
finalinherited
mqttUrl → String?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

appImageCorrectUrl(String url, {dynamic base}) → String
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited